function TestPlot1
% Test plot functions

% Set the plot size and default font
figure;
SetPlotSize ([1.5 1.5 12, 8], 'centimeters');
SetPlotFont ('Times', 10);

% Set the plot colours (darker colours)
SetPlotColors;

% Generate some offset sinusoids
Ngraph = 4;
for (i = 1:Ngraph)
  w(:,i) = (linspace (-pi, pi, 201))';
  Theta = (i - 1) * pi / Ngraph;
  s(:,i) = sin(w(:,i) + Theta);
end

% Set the axis limits prior to calling DashLine
axis ([-pi pi -1.1 1.1]);
axdata = axis;

% Make dash/dot line styles
Pattern{1} = [5 -5]; % Long dash
Pattern{2} = [];     % Line
Pattern{3} = [2 -2]; % Short dash
Pattern{4} = [5 -2 2 -2]; % Long dash - short dash

% Create the dashed lines
for (i = 1:Ngraph)
  [wd{i} sd{i}] = DashLine (w(:,i), s(:,i), Pattern{i});
end

% Plot the data
plot (wd{1}, sd{1}, wd{2}, sd{2}, wd{3}, sd{3}, wd{4}, sd{4});

% Restore the axis limits
axis (axdata);

% Set the tick marks
set (gca, 'XTick', [-pi, -pi/2, 0, pi/2, pi]);
SetXTickLabel ({'-\pi' '-\pi/2' '0' '\pi/2' '\pi'});
set (gca, 'YTick', [-1 -0.5 0 0.5 1]);

% Labels
xlabel ('angle (radians)');
ylabel ('amplitude');

% Add a legend
h = legend ('\theta = 0', '\theta = \pi/4', ...
            '\theta = \pi/2', '\theta = 3\pi/2');
LemonChiffon = [1 0.9725 0.7805];
set (h, 'Color', LemonChiffon);
SetLegendProp (h, 'Pattern', Pattern);

% Add a minor tick between each existing tick
MidTick ('XY');

% Add axes going through the origin
Xaxis;
Yaxis;

% Write the plot to a file
WritePlot ('TestPlot1.eps');

return
