function TestPlot2
% Test plot functions

% Set the plot size and default font
figure;
SetPlotSize ([1.5 1.5 12, 6], 'centimeters');
SetPlotFont ('Times', 10);

% Generate a Hamming window and its frequency response
alpha = 0.08;
N = 48;
b = (1+alpha)/2 - (1-alpha)/2 * cos (pi * (2*(0:N-1)+1)/N);
w = linspace (0, pi, 8193);
hdB = 20 * log10(abs (freqz (b, 1, w)));
hdB = hdB - hdB(1);

% Set the axis limits prior to calling XYmerge
axis ([w(1) w(end) -80 5]);
axdata = axis;

% Merge nearly co-linear vectors
[wm, hdBm] = XYmerge (w, hdB);

% Plot the frequency response
plot (wm, hdBm);

% Restore the axis limits
axis (axdata);

% Set the tick marks
set (gca, 'XTick', [0, pi/4, pi/2, 3*pi/4, pi]);
SetXTickLabel ({'0' '\pi/4' '\pi/2' '3\pi/4', '\pi'});
set (gca, 'YTick', -80:20:0);

% Labels
xlabel ('frequency (radians)');
ylabel ('amplitude (dB)');

% Add a minor tick between each existing tick
MidTick ('XY');

% Write the plot to a file
WritePlot ('TestPlot2.eps');

return
